{% load fk_tags %}
<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="UTF-8" />
        <meta name="viewport" content="width=device-width, initial-scale=1.0" />
        <meta name="description" content="" />
        <meta name="keywords" content="" />
        <title>{{ page.title }}</title>
        {% fk_preloads %}
        {% fk_stylesheets %}
        {% fk_head_scripts %}
    </head>
    <body>
        {% block body %}
        {% endblock body %}
        {% fk_body_scripts %}
    </body>
</html>
